--################################################################
-- written by CrisOHara
-- Version 2
-- 25.04.2023
-- This software is free
--
-- The script is developed for x9lite-S openTx 2.3.11 (but likely to run on some other radio)
-- Cause some of the used values depend on "magic" numbers it may be nessesary to adapt for other radios
-- The hardware dependency is base on the fact that different type of radios do have a different amount of switches.
-- Also different software version may have an effect.
-- So please check on companion first (or at least use a copy of an existing model)
--
-- Script can be used as telemetry script in a telemetry view (but has to run only once so it should be removed after first run)
--   or with execute when selected from the file menu direct from sdcard (that's what I prefer)
-- Be aware that you have to select to model as active model first.
--
-- Hints:
--
--
-- this example script creates: Mixxers to mix Trainer source an stick source 
--
--   CH25  = input student aileron
--   CH26  = input student elevator
--   CH27  = input student throttle
--   CH28  = input student ruder
--
-- no warranty: script is to be used on your own risk
--
--######################################################################


-- ############################# init function ##################
-- global variables
local errorOnIndex = 0;
local indexSwitchLS01, indexSourceTR01, indexSourceMAX, indexSourceCH01, indexSwitchTele, indexSourceRud, lineSizeMID, lineSizeSML

-- function
local function Chadef_init()

local lowWeight = 60;
local highWeight = 80;

--##### defining of Indes for LS01, TR1, CH01, Max ### depends on radio Type ### x9Lite = 36

	chunk, err = loadScript("/SCRIPTS/TOOLS/trainer/indLib.lua");
	if err then
	   errorOnIndex = 1;
	   return;
	   end;
        local script=chunk();
        indexSwitchLS01, indexSourceTR01, indexSourceMAX, indexSourceCH01, indexSwitchTele, indexSourceRud, lineSizeMID, lineSizeSML = script.init();



--#####  create mixer for Trainer (Ch29, CH30, CH31, CH32) ########################

local mixerData = { name, source, weight, offset, switch, multiplex, curveType, curveValue, flightModes, carryTrim, mixWarn, delayUp, delayDown, speedUp, speedDown}
local sourceNr = 0;

-- ######  calibrating students inputs with weight, offset and channelorder ###################

-- creating Mixer Ch25  which does calibrating of aileron  (Tr1 for AETR Student)
	channelNr = 25;
	sourceNr  = indexSourceTR01;
            while (model.getMixesCount(channelNr - 1) > 0) do model.deleteMix(channelNr-1, 0) end;
	    mixerData = { name="Tr-ail", source=sourceNr,  weight=100, offset=0, multiplex=0, curveType=0, curveValue=0, flightModes=512,
                        carryTrim=0, mixWarn=0, delayUp=0, delayDown=0, speedUp=0, speedDown=0}
	    model.insertMix(channelNr-1, 0, mixerData);

-- creating Mixer Ch26  which does calibrating of elevator (Tr2 for AETR Student)
	channelNr = 26;
	sourceNr  = indexSourceTR01 + 1;
            while (model.getMixesCount(channelNr - 1) > 0) do model.deleteMix(channelNr-1, 0) end;
	    mixerData = { name="Tr-ele", source=sourceNr,  weight=100, offset=0, multiplex=0, curveType=0, curveValue=0, flightModes=512,
                        carryTrim=0, mixWarn=0, delayUp=0, delayDown=0, speedUp=0, speedDown=0}
	    model.insertMix(channelNr-1, 0, mixerData);

-- creating Mixer Ch27  which does calibrating of throttle (Tr3 for AETR Student)
	channelNr = 27;
	sourceNr  = indexSourceTR01 + 2;
            while (model.getMixesCount(channelNr - 1) > 0) do model.deleteMix(channelNr-1, 0) end;
	    mixerData = { name="Tr-thr", source=sourceNr,  weight=100, offset=0, multiplex=0, curveType=0, curveValue=0, flightModes=512,
                        carryTrim=0, mixWarn=0, delayUp=0, delayDown=0, speedUp=0, speedDown=0}
	    model.insertMix(channelNr-1, 0, mixerData);

-- creating Mixer Ch28  which does calibrating of ruder    (Tr4 for AETR Student)

	channelNr = 28;
	sourceNr  = indexSourceTR01 + 3;
            while (model.getMixesCount(channelNr - 1) > 0) do model.deleteMix(channelNr-1, 0) end;
	    mixerData = { name="Tr-rud", source=sourceNr,  weight=100, offset=0, multiplex=0, curveType=0, curveValue=0, flightModes=512,
                        carryTrim=0, mixWarn=0, delayUp=0, delayDown=0, speedUp=0, speedDown=0}
	    model.insertMix(channelNr-1, 0, mixerData);

end


-- ############################### run function #####################
local function Chadef_run(event)
	lcd.clear();

	if lineSizeMID == nil then lineSizeMID = 17; lineSizeSML = 9; end
	lcd.drawText (0, 0,"Student Mixers", MIDSIZE);
	lcd.drawText (0, lineSizeMID,"Taranis", MIDSIZE);
	lcd.drawText (0, 2*lineSizeMID,"X9Lite", MIDSIZE);
	lcd.drawText (0, 3*lineSizeMID,"## Created ##", MIDSIZE+INVERS);
	return 0;
end

return { init=Chadef_init, run=Chadef_run };