--################################################################
-- written by CrisOHara
-- Version 1
-- 26 April 2023
-- This software is free
--
-- The script is developed for x9lite-S openTx 2.3.15 (but likely to run on some other radio)
-- Cause some of the used values depend on "magic" numbers it may be nessesary to adapt for other radios
-- The hardware dependency is base on the fact that different type of radios do have a different amount of switches.
-- Also different software version may have an effect.
-- So please check on companion first (or at least use a copy of an existing model)
--
-- Script can be used as telemetry script in a telemetry view (but has to run only once so it should be removed after first run)
--   or with execute when selected from the file menu direct from sdcard (that's what I prefer)
-- Be aware that you have to select to model as active model first.--
--
-- Hints:
-- Many of the numbers used in the functions model.setLogicalSwitch or model.setCustomFunction (like the switch index) are difficult to find out.
-- One possible way to find out is: 
--       Define the logical switch or special function manually in your radio. 
--       Then use the model.getLogicalSwitch or model.getCustomFunction and read out the values.
--  If you need a switch like "|L01 (NOT L01)" try a negativ value (for xLite L02=37 ; |L02=-37)
-- To find the number of the hardware switch or functions you can also count through the scroll menu when you select the 
--   hardwareswitch/function on the radio. (does work for hardwareswitches if they are the first in the scroll list  
--   and does work for "func")
--
-- this example script defines:
--    (standard) logical switches  L15, L16 (used to switch between master/slave)  (L11, L12, L13, L14, L17 are cleared) 
--    this version is with Throttle for student
--
-- This is the standard I use for all my models.
--
-- no warranty: script is to be used on your own risk
--
--######################################################################


-- ############################# init function ##################
-- global variables
local errorOnIndex = 0;
local indexSwitchLS01, indexSourceTR01, indexSourceMAX, indexSourceCH01, indexSwitchTele, indexSourceRud, lineSizeMID, lineSizeSML
-- function
local function LSwBud_init()


--##### defining of Indes for LS01, TR1, CH01, Max ### depends on radio Type ### x9Lite = 36

	chunk, err = loadScript("/SCRIPTS/TOOLS/trainer/indLib.lua");
	if err then
	   errorOnIndex = 1;
	   return;
	   end;
	local script=chunk();
        indexSwitchLS01, indexSourceTR01, indexSourceMAX, indexSourceCH01, indexSwitchTele, indexSourceRud, lineSizeMID, lineSizeSML = script.init();



--#### L11 L12 L13 L14 L15 L16 L17
--#### Trainer #####################################################

local valueID;

	  model.setLogicalSwitch (10, {func=0, v1=0, v2=0, ["and"]=0, delay=0, duration=0 });
	  model.setLogicalSwitch (11, {func=0, v1=0, v2=0, ["and"]=0, delay=0, duration=0 });
	  model.setLogicalSwitch (12, {func=0, v1=0, v2=0, ["and"]=0, delay=0, duration=0 });
	  model.setLogicalSwitch (13, {func=0, v1=0, v2=0, ["and"]=0, delay=0, duration=0 });
	  model.setLogicalSwitch (14, {func=9, v1=2, v2=2, delay=0, duration=0 });
	  model.setLogicalSwitch (15, {func=9, v1=3, v2=3, delay=0, duration=0 });
          model.setLogicalSwitch (16, {func=0, v1=0, v2=0, ["and"]= 0, delay=0, duration=0 });
end

-- ############################### run function #####################
local function LSwBud_run(event)
	lcd.clear();

	if lineSizeMID == nil then lineSizeMID = 17; lineSizeSML = 9; end
	lcd.drawText (0, 0,"Log-Switches", MIDSIZE);
	lcd.drawText (0, lineSizeMID,"by share", MIDSIZE);
	lcd.drawText (0, 2*lineSizeMID,"NO throttle", MIDSIZE);
	if errorOnIndex == 1 then 
		lcd.drawText (0, 3*lineSizeMID,"file indLib not found", MIDSIZE);
	     else
		lcd.drawText (0, 3*lineSizeMID,"## Created ##", MIDSIZE+INVERS);
	     end
	return 0;
end

return { init=LSwBud_init, run=LSwBud_run };